# wifi_qrcode
Generate WiFi Access QR Codes

# Installation

```bash
pip install wifi_qrcode
```

# Usage example

```python
wifi_qrcode --ssid MYWIRELESSNETWORK --auth WPA --password SECRET
```

# Arguments

## Required

* `--ssid`

## Optional

* `--auth`
* `--password`
* `--hidden`
* `--output`
